@@ -85,7 +85,7 @@ pub fn setup_arbitrary_data<F: PrimeField>(
 	arbitrary_input
 }
 
-pub fn setup_circuit<R: Rng, F: PrimeField>(
+pub fn setup_circuit_x5<R: Rng, F: PrimeField>(
 	chain_id: F,
 	leaves: &[F],
 	index: u64,
@@ -96,8 +96,8 @@ pub fn setup_circuit<R: Rng, F: PrimeField>(
 	rng: &mut R,
 	curve: Curve,
 ) -> (Circuit<F>, F, F, F, Vec<F>) {
-	let params3 = setup_params_3::<F>(curve);
-	let params5 = setup_params_5::<F>(curve);
+	let params3 = setup_params_x5_3::<F>(curve);
+	let params5 = setup_params_x5_5::<F>(curve);
 
 	let arbitrary_input = setup_arbitrary_data(recipient, relayer, fee);
 	let (leaf_private, leaf_public, leaf, nullifier_hash) = setup_leaf(chain_id, &params5, rng);
@@ -132,7 +132,54 @@ pub fn setup_circuit<R: Rng, F: PrimeField>(
 	(mc, leaf, nullifier_hash, root, public_inputs)
 }
 
-pub fn setup_random_circuit<R: Rng, F: PrimeField>(rng: &mut R, curve: Curve) -> (Circuit<F>, F, F, F, Vec<F>) {
+pub fn setup_circuit_x17<R: Rng, F: PrimeField>(
+	chain_id: F,
+	leaves: &[F],
+	index: u64,
+	roots: &[F],
+	recipient: F,
+	relayer: F,
+	fee: F,
+	rng: &mut R,
+	curve: Curve,
+) -> (Circuit<F>, F, F, F, Vec<F>) {
+	let params3 = setup_params_x17_3::<F>(curve);
+	let params5 = setup_params_x17_5::<F>(curve);
+
+	let arbitrary_input = setup_arbitrary_data(recipient, relayer, fee);
+	let (leaf_private, leaf_public, leaf, nullifier_hash) = setup_leaf(chain_id, &params5, rng);
+	let mut leaves_new = leaves.to_vec();
+	leaves_new.push(leaf);
+	let (tree, path) = setup_tree_and_create_path(&leaves_new, index, &params3);
+	let root = tree.root().inner();
+	let mut roots_new = roots.to_vec();
+	roots_new.push(root);
+	let set_private_inputs = setup_set(&root, &roots_new);
+
+	let mc = Circuit::new(
+		arbitrary_input.clone(),
+		leaf_private,
+		leaf_public,
+		set_private_inputs,
+		roots_new.clone(),
+		params5,
+		path,
+		root.clone(),
+		nullifier_hash,
+	);
+	let public_inputs = get_public_inputs(
+		chain_id,
+		nullifier_hash,
+		roots_new,
+		root,
+		recipient,
+		relayer,
+		fee,
+	);
+	(mc, leaf, nullifier_hash, root, public_inputs)
+}
+
+pub fn setup_random_circuit_x5<R: Rng, F: PrimeField>(rng: &mut R, curve: Curve) -> (Circuit<F>, F, F, F, Vec<F>) {
 	let chain_id = F::rand(rng);
 	let leaves = Vec::new();
 	let index = 0;
@@ -140,7 +187,20 @@ pub fn setup_random_circuit<R: Rng, F: PrimeField>(rng: &mut R, curve: Curve) ->
 	let recipient = F::rand(rng);
 	let relayer = F::rand(rng);
 	let fee = F::rand(rng);
-	setup_circuit::<R, F>(
+	setup_circuit_x5::<R, F>(
+		chain_id, &leaves, index, &roots, recipient, relayer, fee, rng, curve,
+	)
+}
+
+pub fn setup_random_circuit_x17<R: Rng, F: PrimeField>(rng: &mut R, curve: Curve) -> (Circuit<F>, F, F, F, Vec<F>) {
+	let chain_id = F::rand(rng);
+	let leaves = Vec::new();
+	let index = 0;
+	let roots = Vec::new();
+	let recipient = F::rand(rng);
+	let relayer = F::rand(rng);
+	let fee = F::rand(rng);
+	setup_circuit_x17::<R, F>(
 		chain_id, &leaves, index, &roots, recipient, relayer, fee, rng, curve,
 	)
 }
@@ -181,11 +241,20 @@ pub fn setup_groth16<R: RngCore + CryptoRng, E: PairingEngine>(
 	(pk, vk)
 }
 
-pub fn setup_random_groth16<R: RngCore + CryptoRng, E: PairingEngine>(
+pub fn setup_random_groth16_x5<R: RngCore + CryptoRng, E: PairingEngine>(
 	rng: &mut R,
 	curve: Curve,
 ) -> (ProvingKey<E>, VerifyingKey<E>) {
-	let (circuit, ..) = setup_random_circuit(rng, curve);
+	let (circuit, ..) = setup_random_circuit_x5(rng, curve);
+	let (pk, vk) = Groth16::<E>::circuit_specific_setup(circuit.clone(), rng).unwrap();
+	(pk, vk)
+}
+
+pub fn setup_random_groth16_x17<R: RngCore + CryptoRng, E: PairingEngine>(
+	rng: &mut R,
+	curve: Curve,
+) -> (ProvingKey<E>, VerifyingKey<E>) {
+	let (circuit, ..) = setup_random_circuit_x17(rng, curve);
 	let (pk, vk) = Groth16::<E>::circuit_specific_setup(circuit.clone(), rng).unwrap();
 	(pk, vk)
 }
@@ -221,14 +290,14 @@ mod test {
 		let fee = Bls381::from(0u8);
 		let leaves = Vec::new();
 		let roots = Vec::new();
-		let (circuit, leaf, nullifier, root, public_inputs) = setup_circuit::<_, Bls381>(
+		let (circuit, leaf, nullifier, root, public_inputs) = setup_circuit_x5::<_, Bls381>(
 			chain_id, &leaves, 0, &roots, recipient, relayer, fee, &mut rng, curve,
 		);
 
 		add_members_mock(vec![leaf]);
 
 		// let (pk, vk) = setup_circuit_groth16(&mut rng, circuit.clone());
-		let (pk, vk) = setup_random_groth16::<_, Bls12_381>(&mut rng, curve);
+		let (pk, vk) = setup_random_groth16_x5::<_, Bls12_381>(&mut rng, curve);
 		let proof = prove_groth16(&pk, circuit.clone(), &mut rng);
 		let res = verify_groth16(&vk, &public_inputs, &proof);
 
@@ -257,8 +326,8 @@ mod test {
 		let leaves = Vec::new();
 		let roots = Vec::new();
 
-		let params3 = setup_params_3::<Bls381>(curve);
-		let params5 = setup_params_5::<Bls381>(curve);
+		let params3 = setup_params_x5_3::<Bls381>(curve);
+		let params5 = setup_params_x5_5::<Bls381>(curve);
 
 		let arbitrary_input = setup_arbitrary_data::<Bls381>(recipient, relayer, fee);
 		let (leaf_private, leaf_public, leaf, nullifier_hash) =
@@ -295,7 +364,7 @@ mod test {
 		add_members_mock(vec![leaf]);
 
 		// let (pk, vk) = setup_random_groth16(&mut rng, circuit.clone());
-		let (pk, vk) = setup_random_groth16::<_, Bls12_381>(&mut rng, curve);
+		let (pk, vk) = setup_random_groth16_x5::<_, Bls12_381>(&mut rng, curve);
 		let proof = prove_groth16(&pk, mc.clone(), &mut rng);
 		let res = verify_groth16(&vk, &public_inputs, &proof);
 
@@ -323,14 +392,14 @@ mod test {
 		let fee = Bls381::from(0u8);
 		let leaves = Vec::new();
 		let roots = Vec::new();
-		let (circuit, leaf, nullifier, root, public_inputs) = setup_circuit::<_, Bls381>(
+		let (circuit, leaf, nullifier, root, public_inputs) = setup_circuit_x5::<_, Bls381>(
 			chain_id, &leaves, 0, &roots, recipient, relayer, fee, &mut rng, curve,
 		);
 
 		add_members_mock(vec![leaf]);
 
 		// let (pk, vk) = setup_groth16(&mut rng, circuit.clone());
-		let (pk, vk) = setup_random_groth16::<_, Bls12_381>(&mut rng, curve);
+		let (pk, vk) = setup_random_groth16_x5::<_, Bls12_381>(&mut rng, curve);
 		let proof = prove_groth16::<_, Bls12_381>(&pk, circuit.clone(), &mut rng);
 		let mut proof_bytes = vec![0u8; proof.serialized_size()];
 		proof.serialize(&mut proof_bytes[..]).unwrap();
