@@ -5,10 +5,16 @@ use crate::{
 	merkle_tree::{Config as MerkleConfig, Path, SparseMerkleTree},
 	poseidon::{constraints::CRHGadget, sbox::PoseidonSbox, PoseidonParameters, Rounds, CRH},
 	utils::{
+		// exp 5
 		get_mds_poseidon_bls381_x5_3, get_mds_poseidon_bls381_x5_5,
 		get_mds_poseidon_bn254_x5_3, get_mds_poseidon_bn254_x5_5,
 		get_rounds_poseidon_bls381_x5_3, get_rounds_poseidon_bls381_x5_5,
 		get_rounds_poseidon_bn254_x5_3, get_rounds_poseidon_bn254_x5_5,
+		// exp 17
+		get_mds_poseidon_bls381_x17_3, get_mds_poseidon_bls381_x17_5,
+		get_mds_poseidon_bn254_x17_3, get_mds_poseidon_bn254_x17_5,
+		get_rounds_poseidon_bls381_x17_3, get_rounds_poseidon_bls381_x17_5,
+		get_rounds_poseidon_bn254_x17_3, get_rounds_poseidon_bn254_x17_5,
 	},
 };
 use ark_crypto_primitives::SNARK;
@@ -80,16 +86,16 @@ pub fn setup_tree_and_create_path<F: PrimeField>(
 	(mt, path)
 }
 
-pub fn setup_params_3<F: PrimeField>(curve: Curve) -> PoseidonParameters<F> {
+pub fn setup_params_x5_3<F: PrimeField>(curve: Curve) -> PoseidonParameters<F> {
 	// Making params for poseidon in merkle tree
 	match curve {
-		Bls381 => {
+		Curve::Bls381 => {
 			let rounds3 = get_rounds_poseidon_bls381_x5_3::<F>();
 			let mds3 = get_mds_poseidon_bls381_x5_3::<F>();
 			let params3 = PoseidonParameters::<F>::new(rounds3, mds3);
 			params3
 		},
-		Bn254 => {
+		Curve::Bn254 => {
 			let rounds3 = get_rounds_poseidon_bn254_x5_3::<F>();
 			let mds3 = get_mds_poseidon_bn254_x5_3::<F>();
 			let params3 = PoseidonParameters::<F>::new(rounds3, mds3);
@@ -98,16 +104,16 @@ pub fn setup_params_3<F: PrimeField>(curve: Curve) -> PoseidonParameters<F> {
 	}
 }
 
-pub fn setup_params_5<F: PrimeField>(curve: Curve) -> PoseidonParameters<F> {
+pub fn setup_params_x5_5<F: PrimeField>(curve: Curve) -> PoseidonParameters<F> {
 	// Making params for poseidon in merkle tree
 	match curve {
-		Bls381 => {
+		Curve::Bls381 => {
 			let rounds5 = get_rounds_poseidon_bls381_x5_5::<F>();
 			let mds5 = get_mds_poseidon_bls381_x5_5::<F>();
 			let params5 = PoseidonParameters::<F>::new(rounds5, mds5);
 			params5
 		},
-		Bn254 => {
+		Curve::Bn254 => {
 			let rounds5 = get_rounds_poseidon_bn254_x5_5::<F>();
 			let mds5 = get_mds_poseidon_bn254_x5_5::<F>();
 			let params5 = PoseidonParameters::<F>::new(rounds5, mds5);
@@ -116,6 +122,42 @@ pub fn setup_params_5<F: PrimeField>(curve: Curve) -> PoseidonParameters<F> {
 	}
 }
 
+pub fn setup_params_x17_3<F: PrimeField>(curve: Curve) -> PoseidonParameters<F> {
+	// Making params for poseidon in merkle tree
+	match curve {
+		Curve::Bls381 => {
+			let rounds3 = get_rounds_poseidon_bls381_x17_3::<F>();
+			let mds3 = get_mds_poseidon_bls381_x17_3::<F>();
+			let params3 = PoseidonParameters::<F>::new(rounds3, mds3);
+			params3
+		},
+		Curve::Bn254 => {
+			let rounds3 = get_rounds_poseidon_bn254_x17_3::<F>();
+			let mds3 = get_mds_poseidon_bn254_x17_3::<F>();
+			let params3 = PoseidonParameters::<F>::new(rounds3, mds3);
+			params3
+		},
+	}
+}
+
+pub fn setup_params_x17_5<F: PrimeField>(curve: Curve) -> PoseidonParameters<F> {
+	// Making params for poseidon in merkle tree
+	match curve {
+		Curve::Bls381 => {
+			let rounds5 = get_rounds_poseidon_bls381_x17_5::<F>();
+			let mds5 = get_mds_poseidon_bls381_x17_5::<F>();
+			let params5 = PoseidonParameters::<F>::new(rounds5, mds5);
+			params5
+		},
+		Curve::Bn254 => {
+			let rounds5 = get_rounds_poseidon_bn254_x17_5::<F>();
+			let mds5 = get_mds_poseidon_bn254_x17_5::<F>();
+			let params5 = PoseidonParameters::<F>::new(rounds5, mds5);
+			params5
+		},
+	}
+}
+
 pub fn verify_groth16<E: PairingEngine>(
 	vk: &VerifyingKey<E>,
 	public_inputs: &Vec<E::Fr>,
